@@ -182,10 +182,17 @@ export default {
         return response.data;
     },
     async findPatient(patientId) {
-        const response = (await axios.post(orthancApiUrl + "tools/lookup", patientId));
+        // note: we don't use tools/lookup since it is case insensitive ! https://discourse.orthanc-server.org/t/possible-bug-when-changing-casings-in-patientid-using-explorer2/6124
+        const response = (await axios.post(orthancApiUrl + "tools/find", {
+            "Level": "Patient",
+            "Expand": true,
+            "CaseSensitive": true,
+            "Query": {
+                "PatientID": patientId
+            }
+        }));
         if (response.data.length == 1) {
-            const patient = (await axios.get(orthancApiUrl + "patients/" + response.data[0]['ID']));
-            return patient.data;
+            return response.data[0];
         } else {
             return null;
         }
@@ -383,8 +390,8 @@ export default {
         const response = (await axios.post(orthancApiUrl + "tools/find", payload));
         return response.data;
     },
-    async getStudyInstances(orthancId) {
-        return (await axios.get(orthancApiUrl + "studies/" + orthancId + "/instances")).data;
+    async getStudyInstancesIds(orthancId) {
+        return (await axios.get(orthancApiUrl + "studies/" + orthancId + "/instances?expand=false")).data;
     },
     async getStudyInstancesExpanded(orthancId, requestedTags) {
         let url = orthancApiUrl + "studies/" + orthancId + "/instances?expanded";
@@ -411,7 +418,7 @@ export default {
         }
     },
     async getInstanceTags(orthancId) {
-        return (await axios.get(orthancApiUrl + "instances/" + orthancId + "/tags")).data;
+        return (await axios.get(orthancApiUrl + "instances/" + orthancId + "/tags?ignore-length=VisitComments")).data;
     },
     async getSimplifiedInstanceTags(orthancId) {
         return (await axios.get(orthancApiUrl + "instances/" + orthancId + "/tags?simplify")).data;
